==> smart_energy_data_vald3nir-1.0.9.tar.gz: smart_energy_data_vald3nir-1.0.9/src/smart_energy_data/repository/__init__.py <==
from dataclasses import dataclass, asdict

from toolkit.database.mongodb.mongo_api import MongoAPI
from toolkit.database.mongodb.mongo_dao import MongoDAO

from ..env import DatabaseEnv, mongodb_address


# ----------------------------------------------------------------------------------------------------------------------
class BaseApi(MongoAPI):
    def __init__(self, collection: str, print_curl: bool = False) -> None:
        super().__init__(
            api_url=DatabaseEnv.DATABASE_API.value,
            api_key=DatabaseEnv.DATABASE_API_KEY.value,
            database="smart_energy",
            data_source=DatabaseEnv.DATA_SOURCE.value,
            collection=collection,
            print_curl=print_curl
        )


# ----------------------------------------------------------------------------------------------------------------------

class BaseDAO(MongoDAO):

    def __init__(self, collection: str, database: str = "smart_energy") -> None:
        super().__init__(
            client_url=mongodb_address(),
            project_name=database,
            collection=collection,
        )

    def get_all(self) -> list[dict]:
        return self.find_documents()


# ----------------------------------------------------------------------------------------------------------------------

@dataclass
class BaseDTO:

    def to_json(self) -> dict:
        return asdict(self)

# ----------------------------------------------------------------------------------------------------------------------

==> smart_energy_data_vald3nir-1.1.2.tar.gz: smart_energy_data_vald3nir-1.1.2/src/smart_energy_data/repository/__init__.py <==
from dataclasses import dataclass, asdict

from toolkit.database.mongodb.mongo_api import MongoAPI
from toolkit.database.mongodb.mongo_dao import MongoDAO

from ..project import mongodb_address
from ..project.secret import DatabaseEnv


# ----------------------------------------------------------------------------------------------------------------------
class BaseApi(MongoAPI):
    def __init__(self, collection: str, print_curl: bool = False) -> None:
        super().__init__(
            api_url=DatabaseEnv.DATABASE_API.value,
            api_key=DatabaseEnv.DATABASE_API_KEY.value,
            database=DatabaseEnv.DATABASE_NAME.value,
            data_source=DatabaseEnv.DATA_SOURCE.value,
            collection=collection,
            print_curl=print_curl
        )


# ----------------------------------------------------------------------------------------------------------------------

class BaseDAO(MongoDAO):

    def __init__(self, collection: str) -> None:
        super().__init__(
            client_url=mongodb_address(),
            project_name=DatabaseEnv.DATABASE_NAME.value,
            collection=collection,
        )

    def get_all(self) -> list[dict]:
        return self.find_documents()


# ----------------------------------------------------------------------------------------------------------------------

@dataclass
class BaseDTO:

    def to_json(self) -> dict:
        return asdict(self)

# ----------------------------------------------------------------------------------------------------------------------
